[Asterisk-code-review] spelling: control (asterisk[master])

Josh Soref asteriskteam at digium.com
Sun Nov 7 00:05:24 CDT 2021


Josh Soref has uploaded this change for review. ( https://gerrit.asterisk.org/c/asterisk/+/16834 )


Change subject: spelling: control
......................................................................

spelling: control

Change-Id: I615dce29d36fba7c296073eccefdd5236f4f81f0
---
M addons/ooh323c/src/ooh245.c
M codecs/lpc10/README
M codecs/lpc10/analys.c
M codecs/lpc10/bsynz.c
M codecs/lpc10/decode.c
M codecs/lpc10/dyptrk.c
M codecs/lpc10/encode.c
M codecs/lpc10/lpcdec.c
M codecs/lpc10/lpcini.c
M codecs/lpc10/synths.c
M codecs/lpc10/voicin.c
11 files changed, 128 insertions(+), 128 deletions(-)



  git pull ssh://gerrit.asterisk.org:29418/asterisk refs/changes/34/16834/1

diff --git a/addons/ooh323c/src/ooh245.c b/addons/ooh323c/src/ooh245.c
index fe8ff28..ff4a51c 100644
--- a/addons/ooh323c/src/ooh245.c
+++ b/addons/ooh323c/src/ooh245.c
@@ -1722,7 +1722,7 @@
    	iPAddress->tsapIdentifier = pLogicalChannel->localRtpPort;
    }
 
-   /* media contrcol channel */
+   /* media control channel */
    h2250lcap->mediaControlChannel.t =
                                  T_H245TransportAddress_unicastAddress;
    h2250lcap->mediaControlChannel.u.unicastAddress =  (H245UnicastAddress*)
diff --git a/codecs/lpc10/README b/codecs/lpc10/README
index 30abe4c..7d0d776 100644
--- a/codecs/lpc10/README
+++ b/codecs/lpc10/README
@@ -68,10 +68,10 @@
 
 3.
 
-The f2c output originally had a file called contrl_com.c, that defined
+The f2c output originally had a file called control_com.c, that defined
 a small structure containing a few variables that were used in many
 different functions of the LPC10 code.  Every file containing
-functions that used it defined it as "extern", while contrl_com.c
+functions that used it defined it as "extern", while control_com.c
 actually allocated storage for the structure.  Bill Dorsey, one of the
 lead developers of Nautilus, said that the Microsoft C compiler had
 problems either compiling this file, or linking it with all of the
diff --git a/codecs/lpc10/analys.c b/codecs/lpc10/analys.c
index 5ea0a2d..2bf1464 100644
--- a/codecs/lpc10/analys.c
+++ b/codecs/lpc10/analys.c
@@ -34,7 +34,7 @@
 
 #ifdef P_R_O_T_O_T_Y_P_E_S
 extern int analys_(real *speech, integer *voice, integer *pitch, real *rms, real *rc, struct lpc10_encoder_state *st);
-/* comlen contrl_ 12 */
+/* comlen control_ 12 */
 /*:ref: preemp_ 14 5 6 6 4 6 6 */
 /*:ref: onset_ 14 7 6 4 4 4 4 4 4 */
 /*:ref: placev_ 14 11 4 4 4 4 4 4 4 4 4 4 4 */
@@ -65,9 +65,9 @@
 extern struct {
     integer order, lframe;
     logical corrp;
-} contrl_;
+} control_;
 
-#define contrl_1 contrl_
+#define control_1 control_
 
 /* Table of constant values */
 
@@ -131,7 +131,7 @@
 
 /* Revision 1.7  1996/03/27  18:06:20  jaf */
 /* Commented out access to MAXOSP, which is just a debugging variable */
 /* that was defined in the COMMON block CONTRL in contrl.fh. */
 
 /* Revision 1.6  1996/03/26  19:31:33  jaf */
 /* Commented out trace statements. */
@@ -185,7 +185,7 @@
 /*  RMS */
 /*       Written. */
 /*  RC */
 /*       Indices 1 through ORDER written (ORDER defined in contrl.fh). */
 
 /* This subroutine maintains local state from one call to the next.  If */
 /* you want to switch to using a new audio stream for this filter, or */
@@ -406,9 +406,9 @@
 /* embedded. */
 /* listl and lincnt are not needed for an embedded LPC10 at all. */
 /* 	integer nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /* 	common /contrl/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
 /* 	common /contrl/ quant, nbits */
 /* 	common /contrl/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /*       Arguments to entry PITDEC (below) */
 /* 	Parameters/constants */
 /*  Constants */
@@ -483,24 +483,24 @@
     rcbuf = &(st->rcbuf[0]);
     zpre = &(st->zpre);
 
-    i__1 = 720 - contrl_1.lframe;
+    i__1 = 720 - control_1.lframe;
     for (i__ = 181; i__ <= i__1; ++i__) {
-	inbuf[i__ - 181] = inbuf[contrl_1.lframe + i__ - 181];
-	pebuf[i__ - 181] = pebuf[contrl_1.lframe + i__ - 181];
+	inbuf[i__ - 181] = inbuf[control_1.lframe + i__ - 181];
+	pebuf[i__ - 181] = pebuf[control_1.lframe + i__ - 181];
     }
-    i__1 = 540 - contrl_1.lframe;
+    i__1 = 540 - control_1.lframe;
     for (i__ = 229; i__ <= i__1; ++i__) {
-	ivbuf[i__ - 229] = ivbuf[contrl_1.lframe + i__ - 229];
+	ivbuf[i__ - 229] = ivbuf[control_1.lframe + i__ - 229];
     }
-    i__1 = 720 - contrl_1.lframe;
+    i__1 = 720 - control_1.lframe;
     for (i__ = 25; i__ <= i__1; ++i__) {
-	lpbuf[i__ - 25] = lpbuf[contrl_1.lframe + i__ - 25];
+	lpbuf[i__ - 25] = lpbuf[control_1.lframe + i__ - 25];
     }
     j = 1;
     i__1 = (*osptr) - 1;
     for (i__ = 1; i__ <= i__1; ++i__) {
-	if (osbuf[i__ - 1] > contrl_1.lframe) {
-	    osbuf[j - 1] = osbuf[i__ - 1] - contrl_1.lframe;
+	if (osbuf[i__ - 1] > control_1.lframe) {
+	    osbuf[j - 1] = osbuf[i__ - 1] - control_1.lframe;
 	    ++j;
 	}
     }
@@ -508,10 +508,10 @@
     voibuf[0] = voibuf[2];
     voibuf[1] = voibuf[3];
     for (i__ = 1; i__ <= 2; ++i__) {
-	vwin[(i__ << 1) - 2] = vwin[((i__ + 1) << 1) - 2] - contrl_1.lframe;
-	vwin[(i__ << 1) - 1] = vwin[((i__ + 1) << 1) - 1] - contrl_1.lframe;
-	awin[(i__ << 1) - 2] = awin[((i__ + 1) << 1) - 2] - contrl_1.lframe;
-	awin[(i__ << 1) - 1] = awin[((i__ + 1) << 1) - 1] - contrl_1.lframe;
+	vwin[(i__ << 1) - 2] = vwin[((i__ + 1) << 1) - 2] - control_1.lframe;
+	vwin[(i__ << 1) - 1] = vwin[((i__ + 1) << 1) - 1] - control_1.lframe;
+	awin[(i__ << 1) - 2] = awin[((i__ + 1) << 1) - 2] - control_1.lframe;
+	awin[(i__ << 1) - 1] = awin[((i__ + 1) << 1) - 1] - control_1.lframe;
 /*       EWIN(*,J) is unused for J .NE. AF, so the following shift is
 */
 /*       unnecessary.  It also causes error messages when the C versio
@@ -526,7 +526,7 @@
 	voibuf[i__ * 2] = voibuf[(i__ + 1) * 2];
 	voibuf[(i__ << 1) + 1] = voibuf[((i__ + 1) << 1) + 1];
 	rmsbuf[i__ - 1] = rmsbuf[i__];
-	i__1 = contrl_1.order;
+	i__1 = control_1.order;
 	for (j = 1; j <= i__1; ++j) {
 	    rcbuf[j + i__ * 10 - 11] = rcbuf[j + (i__ + 1) * 10 - 11];
 	}
@@ -541,29 +541,29 @@
 */
 /*       cases, keep BIAS the same. */
     temp = 0.f;
-    i__1 = contrl_1.lframe;
+    i__1 = control_1.lframe;
     for (i__ = 1; i__ <= i__1; ++i__) {
-	inbuf[720 - contrl_1.lframe + i__ - 181] = speech[i__] * 4096.f -
+	inbuf[720 - control_1.lframe + i__ - 181] = speech[i__] * 4096.f -
 		(*bias);
-	temp += inbuf[720 - contrl_1.lframe + i__ - 181];
+	temp += inbuf[720 - control_1.lframe + i__ - 181];
     }
-    if (temp > (real) contrl_1.lframe) {
+    if (temp > (real) control_1.lframe) {
 	*bias += 1;
     }
-    if (temp < (real) (-contrl_1.lframe)) {
+    if (temp < (real) (-control_1.lframe)) {
 	*bias += -1;
     }
 /*   Place Voicing Window */
-    i__ = 721 - contrl_1.lframe;
-    preemp_(&inbuf[i__ - 181], &pebuf[i__ - 181], &contrl_1.lframe, &precoef,
+    i__ = 721 - control_1.lframe;
+    preemp_(&inbuf[i__ - 181], &pebuf[i__ - 181], &control_1.lframe, &precoef,
 	    zpre);
-    onset_(pebuf, osbuf, osptr, &c__10, &c__181, &c__720, &contrl_1.lframe, st);
+    onset_(pebuf, osbuf, osptr, &c__10, &c__181, &c__720, &control_1.lframe, st);
 
 /*       MAXOSP is just a debugging variable. */
 
 /* 	MAXOSP = MAX( MAXOSP, OSPTR ) */
 
-    placev_(osbuf, osptr, &c__10, &obound[2], vwin, &c__3, &contrl_1.lframe,
+    placev_(osbuf, osptr, &c__10, &obound[2], vwin, &c__3, &control_1.lframe,
 	    &c__90, &c__156, &c__307, &c__462);
 /*        The Pitch Extraction algorithm estimates the pitch for a frame
 */
@@ -584,12 +584,12 @@
 /*       of INBUF, and writes indices LBUFH+1-LFRAME = 541 through LBUFH
 */
 /*       = 720 of LPBUF. */
-    lpfilt_(&inbuf[228], &lpbuf[384], &c__312, &contrl_1.lframe);
+    lpfilt_(&inbuf[228], &lpbuf[384], &c__312, &control_1.lframe);
 /*       IVFILT reads indices (PWINH-LFRAME-7) = 353 through PWINH = 540
 */
 /*       of LPBUF, and writes indices (PWINH-LFRAME+1) = 361 through */
 /*       PWINH = 540 of IVBUF. */
-    ivfilt_(&lpbuf[204], ivbuf, &c__312, &contrl_1.lframe, ivrc);
+    ivfilt_(&lpbuf[204], ivbuf, &c__312, &control_1.lframe, ivrc);
 /*       TBDM reads indices PWINL = 229 through */
 /*       (PWINL-1)+MAXWIN+(TAU(LTAU)-TAU(1))/2 = 452 of IVBUF, and writes
 */
@@ -620,7 +620,7 @@
     ipitch = tau[midx - 1];
 /*   Place spectrum analysis and energy windows */
     placea_(&ipitch, voibuf, &obound[2], &c__3, vwin, awin, ewin, &
-	    contrl_1.lframe, &c__156);
+	    control_1.lframe, &c__156);
 /*  Remove short term DC bias over the analysis window, Put result in ABUF
 */
     lanal = awin[5] + 1 - awin[4];
@@ -634,14 +634,14 @@
     i__1 = ewin[5] - ewin[4] + 1;
     energy_(&i__1, &abuf[ewin[4] - awin[4]], &rmsbuf[2]);
 /*   Matrix load and invert, check RC's for stability */
-    mload_(&contrl_1.order, &c__1, &lanal, abuf, phi, psi);
-    invert_(&contrl_1.order, phi, psi, &rcbuf[20]);
-    rcchk_(&contrl_1.order, &rcbuf[10], &rcbuf[20]);
+    mload_(&control_1.order, &c__1, &lanal, abuf, phi, psi);
+    invert_(&control_1.order, phi, psi, &rcbuf[20]);
+    rcchk_(&control_1.order, &rcbuf[10], &rcbuf[20]);
 /*   Set return parameters */
     voice[1] = voibuf[2];
     voice[2] = voibuf[3];
     *rms = rmsbuf[0];
-    i__1 = contrl_1.order;
+    i__1 = control_1.order;
     for (i__ = 1; i__ <= i__1; ++i__) {
 	rc[i__] = rcbuf[i__ - 1];
     }
@@ -131,7 +131,7 @@
 /* Revision 1.7  1996/03/27  18:06:20  jaf */
 /* Commented out access to MAXOSP, which is just a debugging variable */
-/* that was defined in the COMMON block CONTRL in contrl.fh. */
+/* that was defined in the COMMON block CONTRL in control.fh. */
 
 /* Revision 1.6  1996/03/26  19:31:33  jaf */
@@ -185,7 +185,7 @@
 /*       Written. */
 /*  RC */
-/*       Indices 1 through ORDER written (ORDER defined in contrl.fh). */
+/*       Indices 1 through ORDER written (ORDER defined in control.fh). */
 
 /* This subroutine maintains local state from one call to the next.  If */
@@ -406,9 +406,9 @@
 /* listl and lincnt are not needed for an embedded LPC10 at all. */
 /* 	integer nframe, nunsfm, iclip, maxosp, listl, lincnt */
-/* 	common /contrl/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
-/* 	common /contrl/ quant, nbits */
-/* 	common /contrl/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
+/* 	common /control/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
+/* 	common /control/ quant, nbits */
+/* 	common /control/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /*       Arguments to entry PITDEC (below) */
 /* 	Parameters/constants */
diff --git a/codecs/lpc10/bsynz.c b/codecs/lpc10/bsynz.c
index de43b43..a4215cc 100644
--- a/codecs/lpc10/bsynz.c
+++ b/codecs/lpc10/bsynz.c
@@ -36,7 +36,7 @@
 
 #ifdef P_R_O_T_O_T_Y_P_E_S
 extern int bsynz_(real *coef, integer *ip, integer *iv, real *sout, real *rms, real *ratio, real *g2pass, struct lpc10_decoder_state *st);
-/* comlen contrl_ 12 */
+/* comlen control_ 12 */
 /*:ref: random_ 4 0 */
 #endif
 
@@ -45,9 +45,9 @@
 extern struct {
     integer order, lframe;
     logical corrp;
-} contrl_;
+} control_;
 
-#define contrl_1 contrl_
+#define control_1 control_
 
 /* ***************************************************************** */
 
@@ -296,9 +296,9 @@
 /* embedded. */
 /* listl and lincnt are not needed for an embedded LPC10 at all. */
 /* 	integer nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /* 	common /contrl/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
 /* 	common /contrl/ quant, nbits */
 /* 	common /contrl/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /*       Function return value definitions */
 /* 	Parameters/constants */
 /*       KEXC is not a Fortran PARAMETER, but it is an array initialized
@@ -343,7 +343,7 @@
     r__1 = *rmso / (*rms + 1e-6f);
     xy = min(r__1,8.f);
     *rmso = *rms;
-    i__1 = contrl_1.order;
+    i__1 = control_1.order;
     for (i__ = 1; i__ <= i__1; ++i__) {
 	exc2[i__ - 1] = exc2[*ipo + i__ - 1] * xy;
     }
@@ -352,7 +352,7 @@
 /*  Generate white noise for unvoiced */
 	i__1 = *ip;
 	for (i__ = 1; i__ <= i__1; ++i__) {
-	    exc[contrl_1.order + i__ - 1] = (real) (random_(st) / 64);
+	    exc[control_1.order + i__ - 1] = (real) (random_(st) / 64);
 	}
 /*  Impulse doublet excitation for plosives */
 /*       (RANDOM()+32768) is in the range 0 to 2**16-1.  Therefore the
@@ -362,7 +362,7 @@
 /*       least 32 bits (16 isn't enough), and PX should be in the rang
 e */
 /*       ORDER+1+0 through ORDER+1+(IP-2) .EQ. ORDER+IP-1. */
-	px = (random_(st) + 32768) * (*ip - 1) / 65536 + contrl_1.order + 1;
+	px = (random_(st) + 32768) * (*ip - 1) / 65536 + control_1.order + 1;
 	r__1 = *ratio / 4 * 1.f;
 	pulse = r__1 * 342;
 	if (pulse > 2e3f) {
@@ -375,32 +375,32 @@
 	sscale = (real)sqrt((real) (*ip)) / 6.928f;
 	i__1 = *ip;
 	for (i__ = 1; i__ <= i__1; ++i__) {
-	    exc[contrl_1.order + i__ - 1] = 0.f;
+	    exc[control_1.order + i__ - 1] = 0.f;
 	    if (i__ <= 25) {
-		exc[contrl_1.order + i__ - 1] = sscale * kexc[i__ - 1];
+		exc[control_1.order + i__ - 1] = sscale * kexc[i__ - 1];
 	    }
-	    lpi0 = exc[contrl_1.order + i__ - 1];
-	    r__2 = exc[contrl_1.order + i__ - 1] * .125f + *lpi1 * .75f;
+	    lpi0 = exc[control_1.order + i__ - 1];
+	    r__2 = exc[control_1.order + i__ - 1] * .125f + *lpi1 * .75f;
 	    r__1 = r__2 + *lpi2 * .125f;
-	    exc[contrl_1.order + i__ - 1] = r__1 + *lpi3 * 0.f;
+	    exc[control_1.order + i__ - 1] = r__1 + *lpi3 * 0.f;
 	    *lpi3 = *lpi2;
 	    *lpi2 = *lpi1;
 	    *lpi1 = lpi0;
 	}
 	i__1 = *ip;
 	for (i__ = 1; i__ <= i__1; ++i__) {
-	    noise[contrl_1.order + i__ - 1] = random_(st) * 1.f / 64;
-	    hpi0 = noise[contrl_1.order + i__ - 1];
-	    r__2 = noise[contrl_1.order + i__ - 1] * -.125f + *hpi1 * .25f;
+	    noise[control_1.order + i__ - 1] = random_(st) * 1.f / 64;
+	    hpi0 = noise[control_1.order + i__ - 1];
+	    r__2 = noise[control_1.order + i__ - 1] * -.125f + *hpi1 * .25f;
 	    r__1 = r__2 + *hpi2 * -.125f;
-	    noise[contrl_1.order + i__ - 1] = r__1 + *hpi3 * 0.f;
+	    noise[control_1.order + i__ - 1] = r__1 + *hpi3 * 0.f;
 	    *hpi3 = *hpi2;
 	    *hpi2 = *hpi1;
 	    *hpi1 = hpi0;
 	}
 	i__1 = *ip;
 	for (i__ = 1; i__ <= i__1; ++i__) {
-	    exc[contrl_1.order + i__ - 1] += noise[contrl_1.order + i__ - 1];
+	    exc[control_1.order + i__ - 1] += noise[control_1.order + i__ - 1];
 	}
     }
 /*   Synthesis filters: */
@@ -408,9 +408,9 @@
     xssq = 0.f;
     i__1 = *ip;
     for (i__ = 1; i__ <= i__1; ++i__) {
-	k = contrl_1.order + i__;
+	k = control_1.order + i__;
 	sum = 0.f;
-	i__2 = contrl_1.order;
+	i__2 = control_1.order;
 	for (j = 1; j <= i__2; ++j) {
 	    sum += coef[j] * exc[k - j - 1];
 	}
@@ -420,9 +420,9 @@
 /*   Synthesize using the all pole filter  1 / (1 - SUM) */
     i__1 = *ip;
     for (i__ = 1; i__ <= i__1; ++i__) {
-	k = contrl_1.order + i__;
+	k = control_1.order + i__;
 	sum = 0.f;
-	i__2 = contrl_1.order;
+	i__2 = control_1.order;
 	for (j = 1; j <= i__2; ++j) {
 	    sum += coef[j] * exc2[k - j - 1];
 	}
@@ -430,7 +430,7 @@
 	xssq += exc2[k - 1] * exc2[k - 1];
     }
 /*  Save filter history for next epoch */
-    i__1 = contrl_1.order;
+    i__1 = control_1.order;
     for (i__ = 1; i__ <= i__1; ++i__) {
 	exc[i__ - 1] = exc[*ip + i__ - 1];
 	exc2[i__ - 1] = exc2[*ip + i__ - 1];
@@ -441,7 +441,7 @@
     gain = (real)sqrt(ssq / xssq);
     i__1 = *ip;
     for (i__ = 1; i__ <= i__1; ++i__) {
-	sout[i__] = gain * exc2[contrl_1.order + i__ - 1];
+	sout[i__] = gain * exc2[control_1.order + i__ - 1];
     }
     return 0;
 } /* bsynz_ */
@@ -296,9 +296,9 @@
 /* listl and lincnt are not needed for an embedded LPC10 at all. */
 /* 	integer nframe, nunsfm, iclip, maxosp, listl, lincnt */
-/* 	common /contrl/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
-/* 	common /contrl/ quant, nbits */
-/* 	common /contrl/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
+/* 	common /control/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
+/* 	common /control/ quant, nbits */
+/* 	common /control/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /*       Function return value definitions */
 /* 	Parameters/constants */
diff --git a/codecs/lpc10/decode.c b/codecs/lpc10/decode.c
index d58cd08..c5340f5 100644
--- a/codecs/lpc10/decode.c
+++ b/codecs/lpc10/decode.c
@@ -39,7 +39,7 @@
 
 #ifdef P_R_O_T_O_T_Y_P_E_S
 extern int decode_(integer *ipitv, integer *irms, integer *irc, integer *voice, integer *pitch, real *rms, real *rc, struct lpc10_decoder_state *st);
-/* comlen contrl_ 12 */
+/* comlen control_ 12 */
 /*:ref: ham84_ 14 3 4 4 4 */
 /*:ref: median_ 4 3 4 4 4 */
 #endif
@@ -49,9 +49,9 @@
 extern struct {
     integer order, lframe;
     logical corrp;
-} contrl_;
+} control_;
 
-#define contrl_1 contrl_
+#define control_1 control_
 
 /* Table of constant values */
 
@@ -352,9 +352,9 @@
 /* embedded. */
 /* listl and lincnt are not needed for an embedded LPC10 at all. */
 /* 	integer nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /* 	common /contrl/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
 /* 	common /contrl/ quant, nbits */
 /* 	common /contrl/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /*       Function return value definitions */
 
 /*       Parameters/constants */
@@ -412,7 +412,7 @@
 /* 800	FORMAT(1X,' <<ERRCOR IN>>',T32,6X,I6,I5,T50,10I8) */
 /*  If no error correction, do pitch and voicing then jump to decode */
     i4 = detau[*ipitv];
-    if (! contrl_1.corrp) {
+    if (! control_1.corrp) {
 	voice[1] = 1;
 	voice[2] = 1;
 	if (*ipitv <= 1) {
@@ -443,7 +443,7 @@
 	dpit[0] = *iavgp;
     }
     drms[0] = *irms;
-    i__1 = contrl_1.order;
+    i__1 = control_1.order;
     for (i__ = 1; i__ <= i__1; ++i__) {
 	drc[i__ * 3 - 3] = irc[i__];
     }
@@ -522,7 +522,7 @@
     }
 /*  Get unsmoothed RMS, RC's, and PITCH */
     *irms = drms[1];
-    i__1 = contrl_1.order;
+    i__1 = control_1.order;
     for (i__ = 1; i__ <= i__1; ++i__) {
 	irc[i__] = drc[i__ * 3 - 2];
     }
@@ -563,7 +563,7 @@
 /*  the values will be zero. */
 L500:
     if ((icorf & bit[4]) != 0) {
-	i__1 = contrl_1.order;
+	i__1 = control_1.order;
 	for (i__ = 5; i__ <= i__1; ++i__) {
 	    irc[i__] = zrc[i__ - 1];
 	}
@@ -575,7 +575,7 @@
     dpit[1] = dpit[0];
     drms[2] = drms[1];
     drms[1] = drms[0];
-    i__1 = contrl_1.order;
+    i__1 = control_1.order;
     for (i__ = 1; i__ <= i__1; ++i__) {
 	drc[i__ * 3 - 1] = drc[i__ * 3 - 2];
 	drc[i__ * 3 - 2] = drc[i__ * 3 - 3];
@@ -605,7 +605,7 @@
 	irc[i__] = i2 * pow_ii(&c__2, &ishift);
     }
 /*  Decode RC(3)-RC(10) to sign plus 14 bits */
-    i__1 = contrl_1.order;
+    i__1 = control_1.order;
     for (i__ = 3; i__ <= i__1; ++i__) {
 	i2 = irc[i__];
 	ishift = 15 - nbit[i__ - 1];
@@ -617,7 +617,7 @@
 /* 811	FORMAT(1X,'<<DECODE OUT>>',T45,I4,1X,10I8) */
 /*  Scale RMS and RC's to reals */
     *rms = (real) (*irms);
-    i__1 = contrl_1.order;
+    i__1 = control_1.order;
     for (i__ = 1; i__ <= i__1; ++i__) {
 	rc[i__] = irc[i__] / 16384.f;
     }
@@ -352,9 +352,9 @@
 /* listl and lincnt are not needed for an embedded LPC10 at all. */
 /* 	integer nframe, nunsfm, iclip, maxosp, listl, lincnt */
-/* 	common /contrl/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
-/* 	common /contrl/ quant, nbits */
-/* 	common /contrl/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
+/* 	common /control/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
+/* 	common /control/ quant, nbits */
+/* 	common /control/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /*       Function return value definitions */
 
diff --git a/codecs/lpc10/dyptrk.c b/codecs/lpc10/dyptrk.c
index ca195b6..ff5faf6 100644
--- a/codecs/lpc10/dyptrk.c
+++ b/codecs/lpc10/dyptrk.c
@@ -36,7 +36,7 @@
 
 #ifdef P_R_O_T_O_T_Y_P_E_S
 extern int dyptrk_(real *amdf, integer *ltau, integer *minptr, integer *voice, integer *pitch, integer *midx, struct lpc10_encoder_state *st);
-/* comlen contrl_ 12 */
+/* comlen control_ 12 */
 #endif
 
 /* Common Block Declarations */
@@ -44,9 +44,9 @@
 extern struct {
     integer order, lframe;
     logical corrp;
-} contrl_;
+} control_;
 
-#define contrl_1 contrl_
+#define control_1 control_
 
 /* ********************************************************************* */
 
@@ -251,9 +251,9 @@
 /* embedded. */
 /* listl and lincnt are not needed for an embedded LPC10 at all. */
 /* 	integer nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /* 	common /contrl/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
 /* 	common /contrl/ quant, nbits */
 /* 	common /contrl/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /* 	Parameters/constants */
 /*       Local variables that need not be saved */
 /*       Note that PATH is only used for debugging purposes, and can be */
@@ -251,9 +251,9 @@
 /* listl and lincnt are not needed for an embedded LPC10 at all. */
 /* 	integer nframe, nunsfm, iclip, maxosp, listl, lincnt */
-/* 	common /contrl/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
-/* 	common /contrl/ quant, nbits */
-/* 	common /contrl/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
+/* 	common /control/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
+/* 	common /control/ quant, nbits */
+/* 	common /control/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /* 	Parameters/constants */
 /*       Local variables that need not be saved */
diff --git a/codecs/lpc10/encode.c b/codecs/lpc10/encode.c
index f7b4776..cd93330 100644
--- a/codecs/lpc10/encode.c
+++ b/codecs/lpc10/encode.c
@@ -28,7 +28,7 @@
 
 #ifdef P_R_O_T_O_T_Y_P_E_S
 extern int encode_(integer *voice, integer *pitch, real *rms, real *rc, integer *ipitch, integer *irms, integer *irc);
-/* comlen contrl_ 12 */
+/* comlen control_ 12 */
 #endif
 
 /* Common Block Declarations */
@@ -36,9 +36,9 @@
 extern struct {
     integer order, lframe;
     logical corrp;
-} contrl_;
+} control_;
 
-#define contrl_1 contrl_
+#define control_1 control_
 
 /* Table of constant values */
 
@@ -264,9 +264,9 @@
 /* embedded. */
 /* listl and lincnt are not needed for an embedded LPC10 at all. */
 /* 	integer nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /* 	common /contrl/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
 /* 	common /contrl/ quant, nbits */
 /* 	common /contrl/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /*       Parameters/constants */
 /*       These arrays are not Fortran PARAMETER's, but they are defined */
 /*       by DATA statements below, and their contents are never altered.
@@ -280,7 +280,7 @@
     /* Function Body */
 /*  Scale RMS and RC's to integers */
     *irms = (integer)*rms;
-    i__1 = contrl_1.order;
+    i__1 = control_1.order;
     for (i__ = 1; i__ <= i__1; ++i__) {
 	irc[i__] = (integer)(rc[i__] * 32768.f);
     }
@@ -290,7 +290,7 @@
     if (voice[1] != 0 && voice[2] != 0) {
 	*ipitch = entau[*pitch - 1];
     } else {
-	if (contrl_1.corrp) {
+	if (control_1.corrp) {
 	    *ipitch = 0;
 	    if (voice[1] != voice[2]) {
 		*ipitch = 127;
@@ -333,15 +333,15 @@
 	irc[i__] = i2;
     }
 /*  Encode RC(3) - (10) linearly, remove bias then scale */
-    i__1 = contrl_1.order;
+    i__1 = control_1.order;
     for (i__ = 3; i__ <= i__1; ++i__) {
 	i2 = irc[i__] / 2;
-	i2 = (integer)((i2 + enadd[contrl_1.order + 1 - i__ - 1]) * enscl[
-		contrl_1.order + 1 - i__ - 1]);
+	i2 = (integer)((i2 + enadd[control_1.order + 1 - i__ - 1]) * enscl[
+		control_1.order + 1 - i__ - 1]);
 /* Computing MIN */
 	i__2 = max(i2,-127);
 	i2 = min(i__2,127);
-	nbit = enbits[contrl_1.order + 1 - i__ - 1];
+	nbit = enbits[control_1.order + 1 - i__ - 1];
 	i3 = 0;
 	if (i2 < 0) {
 	    i3 = -1;
@@ -356,7 +356,7 @@
 /*     important parameters during non-voiced frames. */
 /*     RC(1) - RC(4) are protected using 20 parity bits */
 /*     replacing RC(5) - RC(10). */
-    if (contrl_1.corrp) {
+    if (control_1.corrp) {
 	if (*ipitch == 0 || *ipitch == 127) {
 	    irc[5] = enctab[(irc[1] & 30) / 2];
 	    irc[6] = enctab[(irc[2] & 30) / 2];
@@ -264,9 +264,9 @@
 /* listl and lincnt are not needed for an embedded LPC10 at all. */
 /* 	integer nframe, nunsfm, iclip, maxosp, listl, lincnt */
-/* 	common /contrl/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
-/* 	common /contrl/ quant, nbits */
-/* 	common /contrl/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
+/* 	common /control/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
+/* 	common /control/ quant, nbits */
+/* 	common /control/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /*       Parameters/constants */
 /*       These arrays are not Fortran PARAMETER's, but they are defined */
diff --git a/codecs/lpc10/lpcdec.c b/codecs/lpc10/lpcdec.c
index 55f8892..5033261 100644
--- a/codecs/lpc10/lpcdec.c
+++ b/codecs/lpc10/lpcdec.c
@@ -40,7 +40,7 @@
 #ifdef P_R_O_T_O_T_Y_P_E_S
 extern int lpcdec_(integer *bits, real *speech);
 extern int initlpcdec_(void);
-/* comlen contrl_ 12 */
+/* comlen control_ 12 */
 /*:ref: chanrd_ 14 5 4 4 4 4 4 */
 /*:ref: decode_ 14 7 4 4 4 4 4 6 6 */
 /*:ref: synths_ 14 6 4 4 6 6 6 4 */
@@ -53,9 +53,9 @@
 extern struct {
     integer order, lframe;
     logical corrp;
-} contrl_;
+} control_;
 
-#define contrl_1 contrl_
+#define control_1 control_
 
 /* Table of constant values */
 
@@ -271,9 +271,9 @@
 /* embedded. */
 /* listl and lincnt are not needed for an embedded LPC10 at all. */
 /* 	integer nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /* 	common /contrl/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
 /* 	common /contrl/ quant, nbits */
 /* 	common /contrl/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /*       Local variables that need not be saved */
 /*       Uncoded speech parameters */
 /*       Coded speech parameters */
@@ -271,9 +271,9 @@
 /* listl and lincnt are not needed for an embedded LPC10 at all. */
 /* 	integer nframe, nunsfm, iclip, maxosp, listl, lincnt */
-/* 	common /contrl/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
-/* 	common /contrl/ quant, nbits */
-/* 	common /contrl/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
+/* 	common /control/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
+/* 	common /control/ quant, nbits */
+/* 	common /control/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /*       Local variables that need not be saved */
 /*       Uncoded speech parameters */
diff --git a/codecs/lpc10/lpcini.c b/codecs/lpc10/lpcini.c
index ced3498..9df0e2b 100644
--- a/codecs/lpc10/lpcini.c
+++ b/codecs/lpc10/lpcini.c
@@ -40,7 +40,7 @@
 
 #ifdef P_R_O_T_O_T_Y_P_E_S
 extern int lpcini_(void);
-/* comlen contrl_ 12 */
+/* comlen control_ 12 */
 /*:ref: initlpcenc_ 14 0 */
 /*:ref: initlpcdec_ 14 0 */
 #endif
@@ -50,9 +50,9 @@
 struct {
     integer order, lframe;
     logical corrp;
-} contrl_;
+} control_;
 
-#define contrl_1 contrl_
+#define control_1 control_
 
 /* ***************************************************************** */
 
@@ -238,12 +238,12 @@
 /* embedded. */
 /* listl and lincnt are not needed for an embedded LPC10 at all. */
 /* 	integer nframe, nunsfm, iclip, maxosp, listl, lincnt */
-/* 	common /contrl/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
-/* 	common /contrl/ quant, nbits */
-/* 	common /contrl/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
-    contrl_1.order = 10;
-    contrl_1.lframe = 180;
-    contrl_1.corrp = TRUE_;
+/* 	common /control/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
+/* 	common /control/ quant, nbits */
+/* 	common /control/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
+    control_1.order = 10;
+    control_1.lframe = 180;
+    control_1.corrp = TRUE_;
     return 0;
 } /* lpcini_ */
 
diff --git a/codecs/lpc10/synths.c b/codecs/lpc10/synths.c
index 2a3179b..affe5cf 100644
--- a/codecs/lpc10/synths.c
+++ b/codecs/lpc10/synths.c
@@ -39,7 +39,7 @@
 
 #ifdef P_R_O_T_O_T_Y_P_E_S
 extern int synths_(integer *voice, integer *pitch, real *rms, real *rc, real *speech, integer *k, struct lpc10_decoder_state *st);
-/* comlen contrl_ 12 */
+/* comlen control_ 12 */
 /*:ref: pitsyn_ 14 12 4 4 4 6 6 4 4 4 6 6 4 6 */
 /*:ref: irc2pc_ 14 5 6 6 4 6 6 */
 /*:ref: bsynz_ 14 7 6 4 4 6 6 6 6 */
@@ -54,9 +54,9 @@
 extern struct {
     integer order, lframe;
     logical corrp;
-} contrl_;
+} control_;
 
-#define contrl_1 contrl_
+#define control_1 control_
 
 /* Table of constant values */
 
@@ -339,9 +339,9 @@
 /* embedded. */
 /* listl and lincnt are not needed for an embedded LPC10 at all. */
 /* 	integer nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /* 	common /contrl/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
 /* 	common /contrl/ quant, nbits */
 /* 	common /contrl/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /*       Parameters/constants */
 /*       Local variables that need not be saved */
 /*       Local state */
@@ -380,7 +380,7 @@
 /* Computing MAX */
     i__1 = min(*pitch,156);
     *pitch = max(i__1,20);
-    i__1 = contrl_1.order;
+    i__1 = control_1.order;
     for (i__ = 1; i__ <= i__1; ++i__) {
 /* Computing MAX */
 /* Computing MIN */
@@ -388,7 +388,7 @@
 	r__1 = min(r__2,.99f);
 	rc[i__] = max(r__1,-.99f);
     }
-    pitsyn_(&contrl_1.order, &voice[1], pitch, rms, &rc[1], &contrl_1.lframe,
+    pitsyn_(&control_1.order, &voice[1], pitch, rms, &rc[1], &control_1.lframe,
 	    ivuv, ipiti, rmsi, rci, &nout, &ratio, st);
     if (nout > 0) {
 	i__1 = nout;
@@ -398,7 +398,7 @@
 d of */
 /*             BUF. */
 
-	    irc2pc_(&rci[j * 10 - 10], pc, &contrl_1.order, &c_b2, &g2pass);
+	    irc2pc_(&rci[j * 10 - 10], pc, &control_1.order, &c_b2, &g2pass);
 	    bsynz_(pc, &ipiti[j - 1], &ivuv[j - 1], &buf[*buflen], &rmsi[j - 1]
 		    , &ratio, &g2pass, st);
 	    deemp_(&buf[*buflen], &ipiti[j - 1], st);
@@ -339,9 +339,9 @@
 /* listl and lincnt are not needed for an embedded LPC10 at all. */
 /* 	integer nframe, nunsfm, iclip, maxosp, listl, lincnt */
-/* 	common /contrl/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
-/* 	common /contrl/ quant, nbits */
-/* 	common /contrl/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
+/* 	common /control/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
+/* 	common /control/ quant, nbits */
+/* 	common /control/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /*       Parameters/constants */
 /*       Local variables that need not be saved */
diff --git a/codecs/lpc10/voicin.c b/codecs/lpc10/voicin.c
index 2d36e2c..58125b5 100644
--- a/codecs/lpc10/voicin.c
+++ b/codecs/lpc10/voicin.c
@@ -39,7 +39,7 @@
 
 #ifdef P_R_O_T_O_T_Y_P_E_S
 extern int voicin_(integer *vwin, real *inbuf, real *lpbuf, integer *buflim, integer *half, real *minamd, real *maxamd, integer *mintau, real *ivrc, integer *obound, integer *voibuf, integer *af, struct lpc10_encoder_state *st);
-/* comlen contrl_ 12 */
+/* comlen control_ 12 */
 /*:ref: vparms_ 14 14 4 6 6 4 4 6 4 4 4 4 6 6 6 6 */
 #endif
 
@@ -48,9 +48,9 @@
 extern struct {
     integer order, lframe;
     logical corrp;
-} contrl_;
+} control_;
 
-#define contrl_1 contrl_
+#define control_1 control_
 
 /****************************************************************************/
 
@@ -414,9 +414,9 @@
 /* embedded. */
 /* listl and lincnt are not needed for an embedded LPC10 at all. */
 /* 	integer nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /* 	common /contrl/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
 /* 	common /contrl/ quant, nbits */
 /* 	common /contrl/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /* 	Parameters/constants */
 /*       Voicing coefficient and Linear Discriminant Analysis variables:
 */
@@ -414,9 +414,9 @@
 /* listl and lincnt are not needed for an embedded LPC10 at all. */
 /* 	integer nframe, nunsfm, iclip, maxosp, listl, lincnt */
-/* 	common /contrl/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
-/* 	common /contrl/ quant, nbits */
-/* 	common /contrl/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
+/* 	common /control/ fsi, fso, fpi, fpo, fbi, fbo, pbin, fmsg, fdebug */
+/* 	common /control/ quant, nbits */
+/* 	common /control/ nframe, nunsfm, iclip, maxosp, listl, lincnt */
 /* 	Parameters/constants */
 /*       Voicing coefficient and Linear Discriminant Analysis variables:

-- 
To view, visit https://gerrit.asterisk.org/c/asterisk/+/16834
To unsubscribe, or for help writing mail filters, visit https://gerrit.asterisk.org/settings

Gerrit-Project: asterisk
Gerrit-Branch: master
Gerrit-Change-Id: I615dce29d36fba7c296073eccefdd5236f4f81f0
Gerrit-Change-Number: 16834
Gerrit-PatchSet: 1
Gerrit-Owner: Josh Soref <jsoref at gmail.com>
Gerrit-CC: Friendly Automation
Gerrit-MessageType: newchange
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.digium.com/pipermail/asterisk-code-review/attachments/20211107/486eea25/attachment-0001.html>


More information about the asterisk-code-review mailing list